@@ -96,9 +96,15 @@ class SSHClient(object):
             )
             log.info(f"{self.__ip}:{self.__port} | ssh connect successfully.")
             return True
+        except OSError as e:
+            log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
+            return False
         except paramiko.ssh_exception.SSHException as e:
             log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
             return False
+        except paramiko.SSHException as e:
+            log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
+            return False
         except Exception as e:
             log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
             return False
